<?php

namespace Drupal\html_import\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\file\Entity\File;

/**
 * Delete imported HTML files.
 *
 * @package Drupal\html_import.
 */
class DeleteHtmlImportFileForm extends ConfirmFormBase {

  /**
   * Flag to delete file by string or int.
   *
   * @var string|int
   */
  protected $source;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delte_html_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return t('Are you sure you want to delete %source ?', ['%source' => $this->source]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('nodeDashbaord.settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $source = '') {
    $this->source = $source;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Load files.
    if ($file = File::load($this->source)) {
      $file->delete();
    }
    else {
      $uri = file_default_scheme() . "://html_file/";
      $extract_detaills = explode('-', $this->source);
      if (strpos($uri, current($extract_detaills)) == FALSE) {
        $dir = file_scan_directory($uri . "/" . current($extract_detaills), '/.*\\.html/');
        foreach ($dir as $key => $value) {
          if ($value->name == end($extract_detaills)) {
            // Delete files from folder.
            unlink($value->uri);
            break;
          }
        }
      }
    }

    // Log message for file delete.
    \Drupal::logger('html_import')->info(
      $this->t('File deleted successfully')
      );
    \Drupal::messenger()->addMessage($this->t('File deleted successfully.'));

    $form_state->setRedirect('nodeDashbaord.settings');
  }

}
